@@ -29,7 +29,7 @@ Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
 
 
 /*
-Configuration file for HomeSite M.A.K.E.R
+Configuration file for Home Site Maker
 
  How to edit the config_site.php file ?
 
@@ -41,10 +41,10 @@ Configuration file for HomeSite M.A.K.E.R
 */
 
 
-$VERSION="homesitemaker-v0.4.2";                         // [STOP] Only for upgrading purporses
-$TITLE="HomeSite M.A.K.E.R";                             // [EDIT] The title of your website
-$DESCRIPTION="The Homesite M.A.K.E.R project home page"; // [EDIT] A brief description of your website
-$URL="http://homesitemaker-devel-local.org";             // [REQUIRED] The URL used to serve your site
+$VERSION="homesitemaker-v0.4.2";                     // [STOP] Only for upgrading purporses
+$TITLE="Homesite Maker";                             // [EDIT] The title of your website
+$DESCRIPTION="The Homesite Maker project home page"; // [EDIT] A brief description of your website
+$URL="http://homesitemaker-devel-local.org";         // [REQUIRED] The URL used to serve your site
 
 $SKIN="white_clouds"; // [OPT] Available skins are rainbow, aqua, simple, black-simple, black-grey and white_clouds
 $HEADER_WIDTH="90%";  // [OPT] Use porcentual value (%) or in pixels
@@ -129,7 +129,7 @@ $SIZE_BOX1="90";
 $WIDTH_BOX1="15%";
 $SKIN_BOX1="$SKIN";
 $COLOR_BOX1="Y";
-$LOGO_BOX1="<div class=\"text6\"><center>HomeSite<br>M.A.K.E.R</center></div>";
+$LOGO_BOX1="<div class=\"text6\"><center>HomeSite<br>Maker</center></div>";
 
 $SIZE_BOX2="90";
 $WIDTH_BOX2="15%";
@@ -165,7 +165,7 @@ $COLOR_LOGIN_BOX="M";
 $SIZE_FOOTER_BOX="55";
 $SKIN_FOOTER_BOX="NO";
 $COLOR_FOOTER_BOX="G";
-$LOGO_FOOTER_BOX="This site is powered by <a href=\"http://homesitemaker.no-ip.org\" target=\"new\">HomeSite M.A.K.E.R</a>".
+$LOGO_FOOTER_BOX="This site is powered by <a href=\"http://homesitemaker.no-ip.org\" target=\"new\">HomeSite Maker</a>".
                  " code. This code is distibuted under <a href=\"http://www.gnu.org/licenses/gpl.html\" target=\"new\">GNU/GPL</a>".
                  " license and are made by melmak from <a href=\"http://www.assl-site.net\" target=\"new\">www.assl-site.net</a>".
                  "<br>All trademarks and copyrights on this page are owned by their respective owners.".
